==> dash-bootstrap-components-1.7.0.tgz: package/src/components/form/FormText.js <==
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {omit} from 'ramda';
import RBFormText from 'react-bootstrap/FormText';
import {bootstrapTextColors} from '../../private/BootstrapColors';

/**
 * Add explanatory text below your input components.
 */
const FormText = props => {
  const {
    children,
    loading_state,
    color,
    style,
    className,
    class_name,
    ...otherProps
  } = props;
  const isBootstrapColor = bootstrapTextColors.has(color);
  const classes = classNames(
    class_name || className,
    isBootstrapColor && `text-${color}`
  );
  return (
    <RBFormText
      style={!isBootstrapColor ? {color: color, ...style} : style}
      className={classes}
      {...omit(['setProps'], otherProps)}
      data-dash-is-loading={
        (loading_state && loading_state.is_loading) || undefined
      }
    >
      {children}
    </RBFormText>
  );
};

FormText.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  id: PropTypes.string,

  /**
   * The children of this component
   */
  children: PropTypes.node,

  /**
   * Defines CSS styles which will override styles previously set.
   */
  style: PropTypes.object,

  /**
   * Often used with CSS to style elements with common properties.
   */
  class_name: PropTypes.string,

  /**
   * **DEPRECATED** Use `class_name` instead.
   *
   * Often used with CSS to style elements with common properties.
   */
  className: PropTypes.string,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  key: PropTypes.string,

  /**
   * Text color, options: primary, secondary, success, warning, danger, info,
   * muted, light, dark, body, white, black-50, white-50 or any valid CSS color of
   * your choice (e.g. a hex code, a decimal code or a CSS color name).
   */
  color: PropTypes.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  loading_state: PropTypes.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: PropTypes.bool,
    /**
     * Holds which property is loading
     */
    prop_name: PropTypes.string,
    /**
     * Holds the name of the component that is loading
     */
    component_name: PropTypes.string
  })
};

export default FormText;

==> dash-bootstrap-components-2.0.0.tgz: package/src/components/form/FormText.js <==
import React from 'react';

import classNames from 'classnames';
import PropTypes from 'prop-types';
import {omit} from 'ramda';
import RBFormText from 'react-bootstrap/FormText';

import {bootstrapTextColors} from '../../private/BootstrapColors';
import {getLoadingState} from '../../private/util';

/**
 * Add explanatory text below your input components.
 */
function FormText({
  children,
  color,
  style,
  class_name,
  className,
  ...otherProps
}) {
  const isBootstrapColor = bootstrapTextColors.has(color);
  const classes = classNames(
    class_name || className,
    isBootstrapColor && `text-${color}`
  );
  return (
    <RBFormText
      style={!isBootstrapColor ? {color: color, ...style} : style}
      className={classes}
      {...omit(['setProps'], otherProps)}
      data-dash-is-loading={getLoadingState() || undefined}
    >
      {children}
    </RBFormText>
  );
}

FormText.propTypes = {
  /**
   * The children of this FormText
   */
  children: PropTypes.node,

  /**
   * The ID of the FormText
   */
  id: PropTypes.string,

  /**
   * Text color, options: primary, secondary, success, warning, danger, info,
   * muted, light, dark, body, white, black-50, white-50 or any valid CSS color of
   * your choice (e.g. a hex code, a decimal code or a CSS color name).
   */
  color: PropTypes.string,

  /**
   * Additional inline CSS styles to apply to the FormText.
   */
  style: PropTypes.object,

  /**
   * Additional CSS classes to apply to the FormText
   */
  class_name: PropTypes.string,

  /**
   * A unique identifier for the component, used to improve performance by React.js
   * while rendering components
   *
   * See https://react.dev/learn/rendering-lists#why-does-react-need-keys for more info
   */
  key: PropTypes.string,

  /**
   * **DEPRECATED** Use `class_name` instead.
   *
   * Additional CSS classes to apply to the FormText
   */
  className: PropTypes.string,

  /**
   * Dash-assigned callback that gets fired when the value changes.
   */
  setProps: PropTypes.func
};

export default FormText;
